@@ -8,12 +8,13 @@ class Step(Base):
                  noise_variance=10**-4, scaler='std', Min=-1, Max=1, num_low=25, num_high=25,
                  gap=-0.1, random_state=0, backend=None):
 
-        synthetic = False
+        synthetic = True
         file_name = None
-        f = None
+        
         X = np.vstack((np.linspace(Min, -gap/2.0, num_low)[:, np.newaxis],
                        np.linspace(gap/2.0, Max, num_high)[:, np.newaxis]))
         y = np.vstack((np.zeros((num_low, 1)), np.ones((num_high, 1))))
+        f = lambda x: y
 
         X_names = ['X']
         y_names = ['y']
